%define anolis_release 1

%global qemu_kvm_arches x86_64 aarch64

%ifarch %{qemu_kvm_arches}
    %global with_qemu_kvm      1
%else
    %global with_qemu_kvm      0
%endif

# Exclude private libraries from autogenerated provides and requires
%global __provides_exclude_from ^%{_libdir}/gnome-boxes/
%global __requires_exclude ^(%%(find %{buildroot}%{_libdir}/gnome-boxes/ -name '*.so' | xargs -n1 basename | sort -u | paste -s -d '|' -))

%global tarball_version %%(echo %{version} | tr '~' '.')
%global major_version %%(echo %%{tarball_version} | cut -d. -f1)

Name:		gnome-boxes
Version:	44.1
Release:	%{anolis_release}%{?dist}
Summary:	A simple GNOME 3 application to access remote or virtual systems

License:	LGPL-2.0-or-later
URL:		https://wiki.gnome.org/Apps/Boxes
Source0:	https://download.gnome.org/sources/%{name}/%{major_version}/%{name}-%{tarball_version}.tar.xz

BuildRequires:	gettext >= 0.19.8
BuildRequires:	meson
BuildRequires:	vala >= 0.36.0
BuildRequires:	yelp-tools
BuildRequires:	pkgconfig(glib-2.0) >= 2.52
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(gtk+-3.0) >= 3.22.20
BuildRequires:	pkgconfig(gtksourceview-4)
BuildRequires:	pkgconfig(gtk-vnc-2.0)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(json-glib-1.0)
BuildRequires:	pkgconfig(libhandy-1)
BuildRequires:	pkgconfig(libvirt-gobject-1.0)
BuildRequires:	pkgconfig(libvirt-gconfig-1.0)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(libosinfo-1.0) >= 1.4.0
BuildRequires:	pkgconfig(libsoup-3.0)
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	pkgconfig(webkit2gtk-4.1)
BuildRequires:	spice-gtk3-vala
BuildRequires:	libosinfo-vala
BuildRequires:	desktop-file-utils

# Pulls in libvirtd + KVM, but no NAT / firewall configs
%if %{with_qemu_kvm}
Requires:	libvirt-daemon-kvm
%else
Requires:	libvirt-daemon-qemu
%endif
Requires:	/usr/bin/virsh

Requires:	libvirt-daemon-config-network

# Needed for unattended installations
Requires:	mtools
Requires:	genisoimage

Requires:	adwaita-icon-theme

%description
gnome-boxes lets you easily create, setup, access, and use:
  * remote machines
  * remote virtual machines
  * local virtual machines
  * When technology permits, set up access for applications on
    local virtual machines

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n %{name}-%{tarball_version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} --with-gnome

# Remove unneeded development files
rm -rf %{buildroot}%{_includedir}/gnome-boxes/
rm -rf %{buildroot}%{_libdir}/gnome-boxes/girepository-1.0/
rm -rf %{buildroot}%{_libdir}/gnome-boxes/pkgconfig/
rm -rf %{buildroot}%{_datadir}/gnome-boxes/gir-1.0/
rm -rf %{buildroot}%{_datadir}/gnome-boxes/vapi/

%generate_compatibility_deps

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Boxes.desktop

%files -f %{name}.lang
%license COPYING copyright
%{_bindir}/gnome-boxes
%{_libdir}/gnome-boxes
%{_libexecdir}/gnome-boxes-search-provider
%{_datadir}/applications/org.gnome.Boxes.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.boxes.gschema.xml
%{_datadir}/gnome-boxes/
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Boxes.SearchProvider.ini
%{_datadir}/icons/hicolor/*/apps/org.gnome.Boxes.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Boxes-symbolic.svg
%{_datadir}/dbus-1/services/org.gnome.Boxes.SearchProvider.service
%{_datadir}/dbus-1/services/org.gnome.Boxes.service
%{_metainfodir}/org.gnome.Boxes.appdata.xml
%dir %{abidir}
%{abidir}/libgovf-0.1.dump


%files doc
%doc README.md NEWS


%changelog
* Wed Apr 05 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 44.1-1
- update to 44.1 and switch to libsoup3

* Sat Mar 18 2023 Zhongling He <zhonglingh@linux.alibaba.com> - 42.3-1
- Init package from upstream
